@@ -23,9 +23,11 @@ from aliyunsdkbssopenapi.endpoint import endpoint_data
 class QueryBillToOSSSubscriptionRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryBillToOSSSubscription')
+		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryBillToOSSSubscription','bssopenapi')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
